import {
  select,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisBottom,
  axisLeft,
  csv,
  schemeRdYlBu
} from 'd3';


import {dataload} from './dataload';
import { colorLegend } from './colorLegend';
import { scatterPlot } from './scatterPlot';


const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(860,80)`);


const colorScale = scaleOrdinal();
const colorValue = d => d.Year;



const title = 'Testing';
const xValue = d => d['year'];
const xAxisLabel = 'year';

  
const yValue = d => d.gdp;
const circleRadius = 10;
const yAxisLabel = 'gdp';

  
const margin = { top: 60, right: 130, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

let data;
let selectedColorValue;


const onClick = d => {
  selectedColorValue = d;
  render();
}

dataload()
  .then(d => {
    data = d
    render()
});


const render = () => {
  colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
    .range(schemeRdYlBu[colorScale.domain().length]); 

    scatterPlotG.call(scatterPlot,{
      data,
      colorValue,
      colorScale,
      selectedColorValue,
      width,
      height,
      margin,
      title,
      xValue,
      xAxisLabel,
      yValue,
      yAxisLabel, 
      circleRadius,
      innerWidth,
      innerHeight
      });

  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 10,
    spacing: 21,
    textOffset: 16,
    backgroundRectWidth:85,
    onClick,
    selectedColorValue
  });
};